#
# spec file for package gnome-shell-extension-desktop-icons
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-shell-extension-desktop-icons
Version:        47.0.12+3
Release:        1.2
Summary:        Desktop icon support for GNOME Shell
License:        GPL-3.0-or-later
Group:          System/GUI/GNOME
URL:            https://gitlab.com/rastersoft/desktop-icons-ng
# Source url disabled as we are using a git checkout via source service
#Source:         https://gitlab.com/rastersoft/desktop-icons-ng/uploads/eaa0b5e8e61258bd108897fc2fbd2da2/ding-%{version}.tar.rst
Source:         ding-%{version}.tar.zst

# Needed for directory ownership
BuildRequires:  gnome-shell >= 45
BuildRequires:  gobject-introspection
BuildRequires:  meson >= 0.44.0
Requires:       gnome-shell
Requires:       nautilus >= 45

%description
This package provides a GNOME Shell extension for showing the contents
of ~/Desktop on the desktop of the Shell. Common file management
operations such as launching, copy/paste, rename and deleting are
supported.

%prep
%autosetup -n ding-%{version}

%build
%meson \
    --localedir=share/gnome-shell/extensions/ding@rastersoft.com/locale
%meson_build

%install
%meson_install

%files
%{_datadir}/glib-2.0/schemas/org.gnome.shell.extensions.ding.gschema.xml
%{_datadir}/gnome-shell/extensions/ding@rastersoft.com/
%dir %{_sysconfdir}/apparmor.d/
%config %{_sysconfdir}/apparmor.d/desktop-icons-ng

%changelog
* Mon Dec 23 2024 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update to version 47.0.12+3:
  * Add support for GNOME 47
  * Use meson to install the apparmor file
  * Add apparmor rules for Ubuntu
  * Updated documentation and fixed bug
  * update ru.po
  * Add 'open with' for folders
  * Fix GFileInfo errors
  * Update HISTORY.md
  * Update Turkish translation
  * Update Ukrainian translation
  * Fix using arrow keys in rename
  * Fix error when opening preferences
  * Update ding.pot
  * The HISTORY.md file is wrong
* Tue Mar 19 2024 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Bring gnome-shell-extension-desktop-icons package back
  (bsc#1221449).
* Tue Mar 19 2024 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update to version 47.0.8+10:
  * Add support for Gnome 46
  * Use nautilus if nemo is selected but not installed
  * Inform users when something is wrong
  * Use an enum for dbus bus type
  * Replace log and logError
  * Update HISTORY.md
  * Try xdg-terminal-exec, gnome-terminal and kgx when opening a terminal
- Drop desktop-icon-gnome-41.patch
- Drop desktop-icons-show-iso-file-icon.patch
* Fri Sep  9 2022 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update desktop-icon-gnome-41.patch: Fix opening prefs.js fail
  (bsc#1199377 bsc#1203262).
* Tue May 10 2022 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Drop desktop-icon-gnome-40.patch.
- Add desktop-icon-gnome-41.patch: Compatible to GNOME 41
  (bsc#1199377).
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream and
  gnome-patch-translation support (jsc#SLE-21105).
* Thu Aug  5 2021 xiaoguang wang <xiaoguang.wang@suse.com>
- Add desktop-icons-show-iso-file-icon.patch: Show ISO file icon as
  default icon.
  (bsc#1183504 glgo#GNOME/World/ShellExtensions/desktop-icons!196)
* Fri Mar 19 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add desktop-icon-gnome-40.patch: Declare compatible to GNOME 40.
- Drop desktop-icons-fix-version-match.patch: Replaced by
  desktop-icon-gnome-40.patch.
* Thu Mar 18 2021 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update to version 20.10.0:
  * Support for Gnome Shell 3.38 and new dialog APIs.
  * Fix dragging several files.
  * Allocate draggable actor before starting the drag.
  * Fix for the native switcheroo controller.
  * Avoid scheduling multiple layoutChildren idlers and other
    fixes.
  * Templates support.
  * Preview files with spacebar.
  * Allow to launch programs with the discrete GPU.
  * Show mounted devices.
  * Set home folder label to localized "Home".
- Drop
  gnome-shell-extension-desktop-icons-add-mount-disk-icon.patch:
  Fixed upstream.
* Fri Nov 20 2020 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add desktop-icons-fix-version-match.patch: Match shell version
  under strict version checking (bsc#1176911).
* Mon Apr 27 2020 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gnome-shell-extension-desktop-icons-add-mount-disk-icon.patch:
  Show mounted device icons
  (jsc#SLE-12572 glgo#GNOME/World/ShellExtensions/desktop-icons!171).
* Fri Apr 17 2020 Xiaoguang Wang <xwang@suse.com>
- Update to version 20.04.0:
  * fileItem.js Fix stretched icons
  * fileItem.js: Add missing semicolons
  * desktopManager: Remove hint text from rename popup
  * general: honor "dont_show_thumbnails" settings
  * Apply suggestion to fileItem.js
  * fileItem.js: show hand cursor whit SINGLE_CLICK
  * desktopManager: clear selected files on desktop refresh
  * DesktopManager: Ignore attribute changes on fileItem if it's not there yet
  * general: Remove fileItemHandlers if item is destroyed
  * createFolderDialog: Use actor Easing instead of Tweener
  * cleanup: Use inheritance for Actor classes instead of composition
  * general: Don't use actor property for native objects
  * createFolterDialog: Port to be a native GObject
  * fileItem.js: always update the metadata of a file
  * general: launch only executable files
  * Update translation
* Thu Nov 14 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Drop superfluous tarball, we use sourceservice during build.
* Wed Nov 13 2019 Xiaoguang Wang <xwang@suse.com>
- Update to version 19.10.2:
  * desktopGrid.js: fix rename button
  * General: Fix thumbnails not centered
  * desktopGrid: Properly inherit Placeholder from a GObject class
  * desktopGrid: Use default upstream styling for rename popup
  * desktopGrid: Derive the RenamePoup from PopupMenu
  * desktopGrid: Open the rename popup only when item menu is
    closed
* Wed Oct  9 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Change License to 'GPL-3.0-or-later', matching what the source
  files claim.
* Tue Oct  8 2019 Xiaoguang Wang <xwang@suse.com>
- Update to version 19.10.1:
  * metadata.json Compatibility only with Gnome Shell 3.34
  * metadata: Support gnome-shell 3.32 and 3.34
  * metadata: Prettify JSON code
  * desktopGrid: Don't emit deprecation warnings when using native
    objects
  * createFolderDialog: Use native GObject for new Shell 3.34
    versions
  * general: Pass the actor to PopupManuManager constructor in new
    shell
  * Update translation
* Wed Sep 18 2019 Xiaoguang Wang <xwang@suse.com>
- Update to version 19.01.4:
  * fileItem.js: Create menus lazily
  * fileItem.js: remove the menu during destruction
  * fileItem.js: disconnect writable-by-others signal
  * fileItem.js: fix code alignment
  * fileItem.js: nullify _setMetadataCancellable
  * fileItem.js: nullify _loadThumbnailDataCancellable
  * fileItem.js: fix property name
  * fileItem.js: avoid error after creating thumbnail
  * fileItem.js: ensure refresh attrs. in .desktop files
  * general: don't use specific monitor for .desktop files
  * Update translation
* Wed Aug 28 2019 Xiaoguang Wang <xwang@suse.com>
- Update to version 19.01.3:
  + Update Polish translation
  + Update Brazilian Portuguese translation
  + fileItem.js: Remove unneeded method call
  + Update POTFILES.in
  + fileItem.js: cancel file monitoring on destroy
  + General: fix opening terminal in folder
  + general: add new files top to bottom, left to right
  + desktopGrid.js: Check shell version for method existence
